14.8. cdist-type__apt_update_index(7) — cdist 4.8.1 documentation

# 14.8. cdist-type__apt_update_index(7)

## 14.8.1. NAME

cdist-type__apt_update_index - Update apt's package index

## 14.8.2. DESCRIPTION

This cdist type runs apt-get update whenever any apt sources have changed.

## 14.8.3. REQUIRED PARAMETERS

None.

## 14.8.4. OPTIONAL PARAMETERS

None.

## 14.8.5. EXAMPLES

    __apt_update_index

## 14.8.6. AUTHORS

Steven Armstrong <steven-cdist--@--armstrong.cc>

## 14.8.7. COPYING

Copyright (C) 2011 Steven Armstrong. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.